##  Why Is Application Rationalization Relevant?
For most of the organizations that are using SAP LeanIX, application rationalization is a key use case. The goal is to clean up the application landscape, achieve efficiency gains, and reduce costs right away.
Application rationalization can also pave the way for other use cases like ERP transformation or AI governance. These initiatives are much easier to realize once you have an efficient IT landscape in place and all redundancies and inefficiencies have been removed.
The following business drivers are typically the starting point for an application rationalization use case:
  * Reduce application costs per year, lowering total cost of ownership (TCO), and freeing up budget for innovation
  * Ensure the business can be more easily scaled by removing redundant, outdated, or ill-fitted applications
  * Minimize technology risk and debt by removing end-of-life and legacy applications
